# -----------------------------------------------------------------------------
# Is Informix up?
sub infUp
{
  ($thishost) = @_;

  if (&check_inhib($thishost) eq "Y")
  {
    $up[$thishost] = "I";
    return ;
  }  

  if ($up[$thishost] eq "D")
  {
    &logit("(No software download)",$thishost);
    return; 
  }  

  if ($t_mustbeup[$thishost] eq "Y")
  {
    $eventsev = "C";
  }
  else
  {
    $eventsev = "I";
  }

  # Start with a clean slate
  $up[$thishost] = "";

  $must_connect = 1;
  &remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$probe[$thishost] status",$tmpfl3,$thishost);
  ##system("cat $tmpfl3");

  if ($up[$thishost] eq "N")     # Remsh error
  {
    logit("(Connect Error)",$thishost);
    return;
  }

  $rmt_netalias_list[$thishost] = "";
  $rmt_hostname[$thishost] = "";

  open(TMPFL3, "$tmpfl3"  ) || &error_msg("Can't open input $tmpfl3 - $!");
  while(<TMPFL3>)
  {
    &parse;

    if ($F1 eq "DBFILECHECKNG:")          
    {
      &event("C",$thishost,"$F2 (DBC Parm) File=$F3 Not Found -or- Not Readable","DBCFileErr","DBA236C",$tmpfl3);
      $up[$thishost] = "N";
    }

    # ROOTPATHCHECKNG: /usr/informix/disks/procdb/rootdbs
    if ($F1 eq "ROOTPATHCHECKNG:")          
    {
      &event("C",$thishost,"ROOTPATH: $F2 Device File Is Not Readable","RootPathNR","DBA239",$tmpfl3);
      $up[$thishost] = "N";
    }

    if ($F1 eq "SESSIONSHWM:")
    {
      if ($F2 > $sessionshwm[$thishost] || $sessionshwm[$thishost] eq "")
      {
        $sessionshwm[$thishost] = $F2;
      }
      &histCreate("infUp()",$thishost,"STA","sessionshwm",$sessionshwm[$thishost]);
    }
    if ($F2 eq "FILECHECK:") 
    {
      $fc_threshold = 28;
      $fc_verb = $F3;
      $fc_age  = $F5;
      $fc_file = $F6;
      if ($fc_verb eq "NotFound")
      {
        &event("C",$thishost,"FILECHECK File=$fc_file Not Found ","FileNF","DBA302",$tmpfl3);
        chop($datew = `date +%C%y/%m/%d-%H:%M:%S`);
        system("echo '$datew - FILECHECK NF  $title[$thishost] fc_verb=$fc_verb fc_file=$fc_file fc_age=$fc_age' >> /tmp/dbamon_filecheck.txt");
      }
      if ($fc_age > $fc_threshold)
      {
        $r1 = int($fc_age / 10);
        $r1 = $r1 * 10;
        $r2 = $r1 + 9;
        $fc_age_rounded = "${r1}-${r2}";
        &event("C",$thishost,"FILECHECK File=$fc_file Is $fc_age_rounded Hours Old (> $fc_threshold Threshold)","FileOld","DBA303",$tmpfl3);
        chop($datew = `date +%C%y/%m/%d-%H:%M:%S`);
        system("echo '$datew - FILECHECK AGE $title[$thishost] fc_verb=$fc_verb fc_file=$fc_file fc_age=$fc_age' >> /tmp/dbamon_filecheck.txt");
      }
    }

    if ($F2 eq "HOSTNAME:") { $rmt_hostname[$thishost] = $F3; }
    if ($F2 eq "NETALIAS:") { $rmt_netalias_list[$thishost] .= "${F3},"; }

    if ($F2 eq "UPTIME:")  #---- New
    {
      $str_c = $F3;
      $str_n = $F4;
      $end_c = $F5;
      $end_n = $F6;
      &uptimeLog($thishost);
    }

  }
  close(TMPFL3);
  return 1 if $up[$thishost] eq "N";  # Return now if there are files missing

  # test
  ##system("cat $tmpfl3 2>&1");
  ##system("grep 'LARGEOBJECT:' $tmpfl3 2>&1");

  if (system("grep 'LARGEOBJECT:' $tmpfl3 > /dev/null 2>&1") == 0)
  {
    open(TMPFL6, ">$tmpfl6") || &error_msg("Can't open output $tmpfl6 - $!");
    print TMPFL6 "<table border=1 bgcolor=skyblue>
      <tr bgcolor=slate>
        <th>$f_s Object Name
        <th>$f_s Object Partnum
        <th>$f_s Size (gB)";
        
    open(IN,"grep 'LARGEOBJECT' $tmpfl3 |") || &error_msg("Can't open input $tmpfl3 - $!");
    $cnt = 0;
    while(<IN>)
    {
      @words = split;
      $objname = $words[2];
      $partnum = $words[3];
      $objsize = $words[4];
      print TMPFL6 "<tr>
        <td><font size=2>$objname
        <td><font size=2>$partnum
        <td align=right><font size=2>$objsize
      ";
      $cnt++;
    }
    close(IN);

    print TMPFL6 "</table> <h5>$cnt Object(s) Found</h5>\n";
    close(TMPFL6);
    &event("W",$thishost,"Informix Object(s) Found Whose Size Exceeds 25gB","LargeObj","DBA238",$tmpfl6);
  }

  if (system("grep 'SQLWONTRUN' $tmpfl3 > /dev/null 2>&1") == 0)
  {
    &event("$eventsev",$thishost,"SQL Will Not Run","SQLErr","DBA237",$tmpfl3);
    $up[$thishost] = "N";
    return 1;
  }

  if (system("grep 'Fatal' $tmpfl3 > /dev/null 2>&1") == 0)
  {
    &event("$eventsev",$thishost,"Fatal Error running onstat -","UpErr","DBA234",$tmpfl3);
    $up[$thishost] = "N";
    return 1;
  }

  ##system("cat $tmpfl3");

  if (system("egrep 'On-Line|Read-Only' $tmpfl3 > $tmpfl2") != 0)
  {
    $up[$thishost] = "N";
    system("cat $tmpfl2");

    if ($t_mustbeup[$thishost] eq "Y")
    {
      &event("C",$thishost,"Informix Instance Not On-Line/Read-Only","IfmxDown","DBA260C",$tmpfl3);
    }
    else
    {
      &event("I",$thishost,"Informix Instance Not On-Line/Read-Only","IfmxDown","DBA261I",$tmpfl3);
    }
  }
  else 
  {
    $up[$thishost] = "Y";
    open(TMPFL2, "$tmpfl2"  ) || &error_msg("Can't open input $tmpfl2 - $!");
    while(<TMPFL2>)
    {
      &parse;
      $sw_version[$thishost] = $F3;
      $db_status[$thishost]  = substr($F5,0,1);
      $dbstatuslong          = $F5;
      $dr_status[$thishost]  = $F6;
      last;
    }
    close(TMPFL2);

    if ($sw_version[$thishost] eq "Version") { $sw_version[$thishost] = $F4 }
    if ($sw_version[$thishost] eq "Dynamic") { $sw_version[$thishost] = $F6 }

    if (index($F0,"Server 2000") > -1)
    {                                      
       $sw_version[$thishost] = $F6;           
       $db_status[$thishost]  = substr($F8,0,1);
       $dbstatuslong          = $F8;
       $dr_status[$thishost]  = $F9;
    }
    elsif ($sw_version[$thishost] eq "Server")  # Is this a 7.3 system
    {                                      
       $sw_version[$thishost] = $F5;         
       $db_status[$thishost]  = substr($F7,0,1);
       $dbstatuslong          = $F7;
       $dr_status[$thishost]  = $F8;
    }
    ##print "F0=$F0 v=$sw_version[$thishost]\n";
    
    $sw_version1 = substr($sw_version[$thishost],0,1);
    $sw_version3 = substr($sw_version[$thishost],0,3);

    if (substr($sw_version[$thishost],5,1) eq "F")
    {
      $v64bit[$thishost] = 1;
    }
    else
    {
      $v64bit[$thishost] = 0;
    }

    $msg = sprintf("OK - Informix Version=%s Status=%s DRStatus=%s",$sw_version[$thishost],$db_status[$thishost],$dr_status[$thishost]);
    &logit($msg,$thishost);

    # Do only if info has not yet been collected

    if ($sn[$thishost] eq "")
    {
      system("rm $tmpfl4 > /dev/null 2>&1");

      if ($count_tables eq "Y")
      {
        logit("(Counting DB Objects)",$thishost);
        &remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$probe[$thishost] count Y",$tmpfl4,$thishost);
      }
      else
      {
        remsh("onstat -;export PATH=\$PATH:$infdir[$thishost]/bin;$probe[$thishost] count N",$tmpfl4,$thishost);
	$num_tables[$thishost] = -1;
      }

      ##system("cat $tmpfl4");

      if (system("grep 'Fatal' $tmpfl4 > /dev/null 2>&1") == 0)
      {
	&event("C",$thishost,"Fatal Error running onstat -","UpErr","DBA234C",$tmpfl4);
	return 1;
      }

      open(TMPFL4, "$tmpfl4"  ) || &error_msg("Can't open input $tmpfl4 - $!");
      while(<TMPFL4>)
      {
        &parse;
	if ($F1 eq "tables")          { $num_tables[$thishost] = $F2 }
	if ($F1 eq "databases")       
        { 
          $num_databases[$thishost] = $F2;
          $dbtot_informix += $F2;
        }
	if ($F1 eq "dblist")          { $dblist[$thishost] .= $F2 . "\n"; }
	if ($F1 eq "appldatabases")   { $num_appldatabases[$thishost] = $F2 }
	if ($F1 eq "dbspaces")        { $num_dbspaces[$thishost] = $F2 }
	if ($F1 eq "disks")           { $num_disks[$thishost] = $F2 }
	if ($F1 eq "segshared")       { $segshared[$thishost] = 1 }
        if ($F1 eq "INFORMIX-OnLine") { $sn[$thishost] = $F7  }
        if ($F1 eq "Informix")        { $sn[$thishost] = $F9  }
        if ($F1 eq "RSAM")            { $sn[$thishost] = $F7  }
	if ($F1 eq "Physical_RAM_MB:") {  $hw_memory[$thishost] = $F2 }
	if ($F1 eq "Num_Processors:")  {  $hw_processors[$thishost] = $F2 }
	if ($F1 eq "CPUTYPE:")        {  $hw_model[$thishost] = $F2 }
	if ($F1 eq "OS_VERSION:")     {  $os_version[$thishost] = $F2 }

        if ($F1 eq "MODE" && $F2 ne "getconf")  
        { 
          $os_mode[$thishost] = $F2  
        }
        if ($F1 eq "HP-UX")
        {
          $os_version[$thishost] = substr($F3,2);
        }
        if (substr($F1,0,4) eq "9000")
        {
          @words = split(/\//,$F0);
	  $model = $words[2];
          if ($model eq "") { $model = $F1; }
          $hw_model[$thishost] = $model;
        }
        if ($F1 eq "BDFIFMXDIR:")
        {
          $bdfsize = $F2;
          $bdfused = $F3;
          $bdfaval = $F4;
          $bdfpct  = $F5;
          $bdfname = $F6;
          $bdfflag = $F7;
          if ($bdfflag ne "OK")
          {
            if ($bdfflag eq "C")
            {
              &event("C",$thishost,"INFORMIXDIR Filesystem is $bdfpct full ($bdfaval MB Free).","IfmxDirFull","DBA265C",$tmpfl4);
            }
            else
            {
              &event("C",$thishost,"Error running 'bdf \$INFORMIXDIR'","IfmxDirErr","DBA266C",$tmpfl4);
            }
          }
        }
      }
      close(TMPFL4);
    }
  }

  #---- Read star_contacts
  &readCMDBContacts($thishost) if $rmt_hostname[$thishost] ne $hostfix[$thishost];

  &logDetails($thishost,"<h3>Informix Instance Data</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
  &logDetails($thishost,"<tr><td>$f_s <b>Informix Status:<td align=right>$f_s $db_status[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR:<td align=right>$f_s $infdir[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXSERVER:<td align=right>$f_s $server[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXSQLHOSTS:<td align=right>$f_s $sqlhosts[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>ONCONFIG:<td align=right>$f_s $config[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Informix Version:<td align=right>$f_s $sw_version[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Informix Serial Number:<td align=right>$f_s $sn[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Number of Databases:<td align=right>$f_s $num_databases[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Number of DBSpaces:<td align=right>$f_s $num_dbspaces[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Number of Tables:<td align=right>$f_s $num_tables[$thishost]<td>(-1 if dbamonrc Count_Tables: = N)");
  &logDetails($thishost,"<tr><td>$f_s <b>Number of Disks Containing Informix Data:<td align=right>$f_s $num_disks[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Number of Informix Shared Memory Segments:<td align=right>$f_s $segshared[$thishost]<td>(Shared Segments are BAD)");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Name:<td align=right>$f_s $bdfname<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Size(MB):<td align=right>$f_s $bdfsize<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Used(MB):<td align=right>$f_s $bdfused<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Available(MB):<td align=right>$f_s $bdfaval<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Percent Full:<td align=right>$f_s $bdfpct<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>INFORMIXDIR FS Status Flag:<td align=right>$f_s $bdfflag<td>");
  &logDetails($thishost,"<tr><td>$f_s <b>Informix Concurrent Sessions HWM:<td align=right>$f_s $sessionshwm[$thishost]");
  &logDetails($thishost,"</table><hr>");

  &logDetails($thishost,"<h3>CMDB Data</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
  &logDetails($thishost,"<tr><td>$f_s <b>CMDB Contacts:<td>$f_s $star_contacts[$thishost] ");
  &logDetails($thishost,"</table><hr>");

  &logDetails($thishost,"<h3>Server Data</h3>");
  &logDetails($thishost,"<table border=1 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=slate><th>Parameter<th>Value<th>Comments</tr>");
  &logDetails($thishost,"<tr><td>$f_s <b>OS Type:<td align=right>$f_s $os[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>OS Version:<td align=right>$f_s $os_version[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>OS Mode:<td align=right>$f_s $os_mode[$thishost]<td>(64 or Blank)");
  &logDetails($thishost,"<tr><td>$f_s <b>Server Type:<td align=right>$f_s $hw_model[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Server Memory (MB):<td align=right>$f_s $hw_memory[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Server Processor Count:<td align=right>$f_s $hw_processors[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Fully-Qualified Hostname<td align=right>$f_s $fqhostname[$thishost]");
  &logDetails($thishost,"<tr><td>$f_s <b>Altered Hostname<td align=right>$f_s $hostfix[$thishost]");
  &logDetails($thishost,"</table><hr>");

  if ($sw_version[$thishost] lt $ver_informix_low  || $ver_informix_low eq "" ) { $ver_informix_low  = $sw_version[$thishost] }
  if ($sw_version[$thishost] gt $ver_informix_high || $ver_informix_high eq "") { $ver_informix_high = $sw_version[$thishost] }

  # 
  # Process network aliases
  #

  # Determine whether we have any hostname alias
  $alias_list[$thishost] = "";

  ##print "fqh=$fqhostname[$thishost] rmth=$rmt_hostname[$thishost] rmtn=$rmt_netalias_list[$thishost]\n";

  # First, see if net alias was used and hostname differs
  if ($fqhostname[$thishost] !~ /^$rmt_hostname[$thishost]/) 
  {
    $alias_list[$thishost] .= "${rmt_hostname[$thishost]}.${serverloc[$thishost]},";
  }

  if ($rmt_hostname[$thishost] !~ /^$hostfix[$thishost]/)
  {
    $alias_list[$thishost] .= "${hostfix[$thishost]}.${serverloc[$thishost]},";
  }

  if ($auto_detect_aliases eq "Y")
  {
    # Next, see if non-alias was used and net alias differs
    @words= split(/,/,$rmt_netalias_list[$thishost]);
    foreach $alias (@words)
    {
      print "found rmt_netalias_list entry $alias\n";
      if ($fqhostname[$thishost] ne $alias)
      {
        $alias_list[$thishost] .= "${alias},";
      }
    }

    ##print "ali=$alias_list[$thishost] \n";

    if ($alias_list[$thishost] ne "")
    {
      &logDetails($thishost,"<h3>Hostname Alias(es)</h3>");
      &logDetails($thishost,"<table border=1>");
      &logDetails($thishost,"<tr bgcolor=slate><th>Alias Name</tr>");

      @words= split(/,/,$alias_list[$thishost]);
      foreach $word (@words)
      {
        &logDetails($thishost,"<tr><td><b>$word");
      }

      &logDetails($thishost,"</table><hr>");
    }
  }

  #
  # Terminate
  #

  &function_cleanup();

  # Read SWVer data

  foreach (@swver_data)
  {
    next if $_ !~ /^$dbmsout[$thishost]/;
    @words = split;
    $this_family = $words[1];
    $this_minver = $words[2];

    ##print "$titleraw[$thishost] $sw_version[$thishost] - Found this_family=$this_family this_minver=$this_minver\n";

    # Continue only if this is OUR family
    next if $sw_version[$thishost] !~ /^$this_family/;

    $z = length($this_minver);
    if (substr($sw_version[$thishost],0,$z) lt $this_minver)
    {
      &event("U",$thishost,"$dbmsout[$thishost] Version $sw_version[$thishost] is older than the minimum 'good' version ($this_minver) for this family ($this_family)","SWVER-OldVer","DBA652");
    }
  }
}     
# -----------------------------------------------------------------------------
1;
